summaryrefslogtreecommitdiffstats
path: root/examples/pyTDEHTMLPart.py
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:42 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:09:42 -0600
commit2df6bde18ab40472f2df8637cf6456cb80dc2329 (patch)
tree5a4362124ff46786fce835d2f1e7d583c92a5670 /examples/pyTDEHTMLPart.py
parentbe6cfa4b990910e65e8d2f4f212eba3f7da6ee72 (diff)
downloadpytde-2df6bde18ab40472f2df8637cf6456cb80dc2329.tar.gz
pytde-2df6bde18ab40472f2df8637cf6456cb80dc2329.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'examples/pyTDEHTMLPart.py')
-rw-r--r--examples/pyTDEHTMLPart.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/pyTDEHTMLPart.py b/examples/pyTDEHTMLPart.py
index 4f31e2b..6dd3397 100644
--- a/examples/pyTDEHTMLPart.py
+++ b/examples/pyTDEHTMLPart.py
@@ -24,7 +24,7 @@ additional code to make this do something useful. The
seem to provide much help. Also, to follow links, you
probably need to connect some signals to slots. I
haven't tried it, but this should work with a plain
-KMainWindow or other widget too.
+TDEMainWindow or other widget too.
The KDE website also incorporates gifs, jpegs, and
I believe CSS too. Playing around with some other
@@ -45,7 +45,7 @@ lifted from the KDE classref.
from tdecore import TDECmdLineArgs, KURL, TDEApplication, i18n, TDEAboutData, BarIcon, KLibLoader
-from tdeui import KMainWindow, KMessageBox, KAction, KStdAction, KKeyDialog, KEditToolbar
+from tdeui import TDEMainWindow, KMessageBox, TDEAction, KStdAction, KKeyDialog, KEditToolbar
from qt import TQString, TQStringList
@@ -64,8 +64,8 @@ TRUE = not FALSE
TOOLBAR_EXIT = 0
TOOLBAR_OPEN = 1
# Note that we use KParts.MainWindow, not KMainWindow as the superclass
# (KParts.MainWindow subclasses KMainWindow). Also, be sure the 'apply'
# clause references KParts.MainWindow - it's a hard bug to track down
# if it doesn't.
@@ -64,8 +64,8 @@ TRUE = not FALSE
TOOLBAR_EXIT = 0
TOOLBAR_OPEN = 1
-# Note that we use KParts.MainWindow, not KMainWindow as the superclass
-# (KParts.MainWindow subclasses KMainWindow). Also, be sure the 'apply'
+# Note that we use KParts.MainWindow, not TDEMainWindow as the superclass
+# (KParts.MainWindow subclasses TDEMainWindow). Also, be sure the 'apply'
# clause references KParts.MainWindow - it's a hard bug to track down
# if it doesn't.